#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <unistd.h>
#include <stdlib.h>
#include <stdint.h>
#include <time.h>
#include <wiringPi.h>
#include <wiringPiI2C.h>

#define WHO_AM_I		0x00
#define SMPLRT_DIV		0x15
#define DLPF_FS			0x16
#define GYRO_XOUT_H		0x1D
#define GYRO_XOUT_L		0x1E
#define GYRO_YOUT_H		0x1F
#define GYRO_YOUT_L		0x20
#define GYRO_ZOUT_H		0x21
#define GYRO_ZOUT_L		0x22

#define DLPF_CFG_0		1<<0
#define DLPF_CFG_1		1<<1
#define DLPF_CFG_2		1<<2
#define DLPF_FS_SEL_0	1<<3
#define DLPF_FS_SEL_1	1<<4

#define ITG_ADRESS		0x68

int main()
{
	int nCompass;
	if((nCompass = wiringPiI2CSetup(ITG_ADRESS)) == -1)
	{
		printf("Unable to initialise I2C");
		return 1;
	}
	// Configure the gyroscope
	// FS_SEL=3 : Set the gyroscope scale for the outputs to +/-2000 degrees per second
	// DLPF_CFG=1 : Low Pass Filter Bandwidth = 188Hz, Internal Sample Rate = 1kHz
	wiringPiI2CWriteReg8(nCompass, DLPF_FS, (DLPF_FS_SEL_0|DLPF_FS_SEL_1|DLPF_CFG_0));
	
	// F_sample = F_internal / ( divider + 1 )
	// sample rate = 1kHz / ( 9 + 1 ) = 100Hz
	// Set the sample rate to 100 hz, 10ms per sample
	wiringPiI2CWriteReg8(nCompass, SMPLRT_DIV, 9);
	
	int xRate, yRate, zRate, i;
	unsigned char high[3], low[3], result[3];
	
	while(1)
	{
		high[0]=wiringPiI2CReadReg8(nCompass,GYRO_XOUT_H);
		low[0]=wiringPiI2CReadReg8(nCompass,GYRO_XOUT_L);
		
		high[1]=wiringPiI2CReadReg8(nCompass,GYRO_YOUT_H);
		low[1]=wiringPiI2CReadReg8(nCompass,GYRO_YOUT_L);
		
		high[2]=wiringPiI2CReadReg8(nCompass,GYRO_ZOUT_H);
		low[2]=wiringPiI2CReadReg8(nCompass,GYRO_ZOUT_L);
		
		for(i = 0; i<3; i++)
		{
			result[i] = (high[i] <<8) | low[i];
		}
		
		printf("x = %i, y = %i, z=%i\n" ,result[0],result[1],result[2]);
		delay(1000);
	}
	
	return 0;
	
}